@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: yesod
 version: 1.4.2.1
-id: yesod-1.4.2.1-12eaeffb36448c79e6acfdbc4e91840d
-key: yesod_C7Od2DtBTdb5dwjD74Jc2p
+id: yesod-1.4.2.1-8b4338149b141e1ed847820ad7f5280a
+key: yesod_AlcJh8xmwGEBukAFw0c8fH
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -21,19 +21,19 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-1.4.2.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-1.4.2.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-1.4.2.1
-hs-libraries: HSyesod-1.4.2.1-C7Od2DtBTdb5dwjD74Jc2p
+hs-libraries: HSyesod-1.4.2.1-AlcJh8xmwGEBukAFw0c8fH
 depends:
     aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     blaze-html-0.8.1.1-1d54daeba5477a1aa0462b832a558865
     blaze-markup-0.7.0.3-fed4a147945def017f9ea9594b30666a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    conduit-extra-1.1.13.1-9eaf94b1885f7c12e1eeebbc86766f62
+    conduit-extra-1.1.13.1-49d5b7e57d33a6d70b83744864ccf557
     data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
     directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
-    fast-logger-2.4.1-5b4c33804a079c795a3744fd9f8cdcd3
-    monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
-    monad-logger-0.3.18-e41795701bd26d2e948311dc59f0bce2
+    fast-logger-2.4.2-7b6f5f8fb22250e162469fc6d2b0305e
+    monad-control-1.0.1.0-0cce93e14e6c79e66d2dc881e1ab9f6e
+    monad-logger-0.3.18-0092336dcf2d8f29e67bd77a9cfcb547
     safe-0.3.9-b613242f536083d5bb04920ede356aea
     semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
     shakespeare-2.0.8-88acbcac23cb55d5f3c82ebba9b11159
@@ -44,14 +44,14 @@ depends:
     unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
     unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
     wai-3.2.0.1-d9757c75f497737a542bd24e4c437c56
-    wai-extra-3.0.15-2f88b45989ced36024c3ff3943866d23
-    wai-logger-2.2.4.1-fb66803d5627851b4e6cf4f9505489de
-    warp-3.2.4-afffa286f2a73716d3c875d3f70e8c61
-    yaml-0.8.16-50dd72d7df25e45cd672d7359cb18648
-    yesod-auth-1.4.13-de84484713f9e6a3bd5378a97a05d337
-    yesod-core-1.4.20-0795e5dd1fccda51b978355252f3f0a8
-    yesod-form-1.4.7-f6d1e11ea63e1cbc5a2a6488d647899b
-    yesod-persistent-1.4.0.4-46b19a60c1c766dabb361044b5599141
+    wai-extra-3.0.15-9c142ea00c97b43b02c895bca19b6780
+    wai-logger-2.2.4.1-214823995b5ac6bfbcb07df3a337df83
+    warp-3.2.6-828a707afef115eb99ae18cc2d425cf2
+    yaml-0.8.16-456c08a298c79f92e1296e690079eee9
+    yesod-auth-1.4.13-3f3a4c2b9e10fa399d34c2d1bda9a652
+    yesod-core-1.4.20-b033425e59f14830b0f582c5aa97dfc9
+    yesod-form-1.4.7-6a275c9e9130fcb166b96e9c28a6cb8b
+    yesod-persistent-1.4.0.4-ad1a95adedfa128856dec4233422bbe5
 haddock-interfaces: /usr/share/doc/haskell-yesod/html/yesod.haddock
 haddock-html: /usr/share/doc/haskell-yesod/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
